#!/usr/bin/perl

use strict;
use HSPC::WebDB;
use HSPC::MT::PluginConfig::PP;

use constant PLUGIN_ID   => 'BT_CLIEOP03';
use constant TEMPLATE_ID => 'BT_Clieop03';

my $afile='/var/opt/hspc-root/template/HSPC/Plugin/PM/BT_Clieop03/agreement.tmpl';
unless ( -e $afile ) {
	system("touch $afile; chmod 644 $afile;");
}

if (is_table_exists(table=>'vendor_pp_plugin') 
	&& is_table_exists(table=>'pp_plugin_clieop03') )
{
	my $rows = 
	  select_hashrows(q|
			SELECT
				vendor_pp_plugin.vendor_id,
				vendor_pp_plugin.plugin_id,
				vendor_pp_plugin.is_active,
				vendor_pp_plugin.banner_text,
				pp_plugin.title,
				pp_plugin.is_autopay_supported
			FROM 
				vendor_pp_plugin, pp_plugin
			WHERE
				vendor_pp_plugin.plugin_id = pp_plugin.id AND
				vendor_pp_plugin.plugin_id = ?
		|, &PLUGIN_ID );

	my %config_map = (
		account_number     => 'account_number',

		file_sequence_num  => 'file_sequence_num',
		fixed_desc         => 'fixed_desc',
		item_desc          => 'item_desc',
		last_sequence_date => 'last_sequence_date',
		order_party_name   => 'order_party_name',
		sender_id          => 'sender_id',
		test_code          => 'test_code',
	);

	exit 0 unless $rows;

	foreach my $plugin (@$rows) {
		my $config = 
		  select_hashrows(q|
				SELECT
					name, value
				FROM 
					pp_plugin_clieop03_config
				WHERE
					provider_id = ?
			|, $plugin->{vendor_id} );

		if ( $config && @$config ) {
	
			my $new_plugin = HSPC::MT::PluginConfig::PP->new();
	
			$new_plugin->vendor_id( $plugin->{vendor_id} );
			$new_plugin->is_active( $plugin->{is_active} );
			$new_plugin->plugin_type('PP');
			$new_plugin->name( $plugin->{title} );

			my $conf = {};
			my $agreement_text;
			foreach my $c (@$config) {
				$conf->{$config_map{$c->{name}}} = $c->{value}
					if exists $config_map{$c->{name}};
				$agreement_text = $c->{value}
					if $c->{name} eq 'agreement_text';
			}

			$new_plugin->config_data( $conf );
	
			$new_plugin->template_id( &TEMPLATE_ID );
	
			$new_plugin->banner_text( $plugin->{banner_text} );
	
			$new_plugin->is_direct( $plugin->{is_autopay_supported} );
			$new_plugin->save();
	
			if ($new_plugin->id()) {
				if ( $agreement_text && -z $afile ) {
					open (AFILE, "> $afile");
					print AFILE $agreement_text;
					close AFILE;
				}

				select_run(q|
					insert into plugin_pp_paytypes (config_id, type, template_id) values (?,?,?)|,
					$new_plugin->id(), 'BT_Clieop03', 'BT_Clieop03'
				);
			
				## upgrade orders payed by this plugin
				select_run(q|
					UPDATE
						ar_doc_rb, ar_doc
					SET
						ar_doc_rb.plugin_id = ? 
					WHERE
						ar_doc_rb.ar_doc_id = ar_doc.ar_doc_id 
						AND ar_doc.vendor = ?
						AND ar_doc_rb.plugin_id = ?|,
						$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID );
	
				## upgrade batches generated by this plugin
				select_run(q|
					UPDATE
						bm_doc_batch
					SET
						plugin_id = ?
					WHERE
						vendor_id = ?
						AND plugin_id = ?|,
					$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID
				);

				## Update TransLog
				select_run(q|
					UPDATE
						pp_trans_log, account
					SET
						pp_trans_log.plugin_id = ?
					WHERE
						pp_trans_log.account_no = account.account_no
						AND account.vendor = ?
						AND pp_trans_log.plugin_id = ?|,
						$new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID 
				);
			}
		}
	}
}

## update reseller config
select_run(
	q|UPDATE reseller_config_plugin SET plugin_id = ? WHERE plugin_id = ?|,
	&TEMPLATE_ID,
	&PLUGIN_ID
);

